@@ -11,6 +11,10 @@ METADATA_DIR="${REPO_DIR}/deploy/metadata/performance-addon-operator"
 
 IMAGE_BUILD_CMD=${IMAGE_BUILD_CMD:-podman}
 
-CSV_VERSION=${CSV_VERSION:-"4.5.4"}
-PREV_CSV_VERSION=${PREV_CSV_VERSION:-"4.4.0"}
-CSV_CHANNEL=${CSV_CHANNEL:-"4.5"}
+CSV_VERSION=${CSV_VERSION:-"4.8.0"}
+PREV_CSV_VERSION=${PREV_CSV_VERSION:-"4.7.0"}
+CSV_CHANNEL=${CSV_CHANNEL:-"4.8"}
+
+MIN_KUBE_VERSION=${MIN_KUBE_VERSION:-"1.20.0"}
+
+ANNOTATIONS_FILE="${REPO_DIR}/hack/annotations.json"
